@@ -12,7 +12,6 @@ from wagtail.admin.edit_handlers import FieldPanel
 from ..bakery.models import BuildableWagtailBakeryModel
 from ..amp.mixins import AmpMixin
 from ..amp.utils import amp_mode_active
-from ..snippets import Menu, IconSnippet
 from .. import constants
 from ..blocks import \
     MediaText, \
@@ -31,9 +30,14 @@ from ..blocks import \
     Embed, \
     HowTo, \
     FAQPage
+from ...loader import get_model
 
 
-class GenericPage(Page):
+Menu = get_model('cms', 'Menu')
+IconSnippet = get_model('cms', 'IconSnippet')
+
+
+class AGenericPage(Page):
     feed_image = models.ForeignKey(
         'wagtailimages.Image',
         null=True,
@@ -119,9 +123,10 @@ class GenericPage(Page):
 
     class Meta:
         abstract = True
+        app_label = 'cms'
 
     def get_context(self, request, *args, **kwargs):
-        context = super(GenericPage, self).get_context(request)
+        context = super(AGenericPage, self).get_context(request)
         context['env'] = settings.TYPENV
         context['icons'] = {}
         DEFAULT_LINK = '/static/webspace/img/svg/default.svg'
@@ -136,7 +141,7 @@ class GenericPage(Page):
     def get_breadcrumbs(self):
         #  FIXME: filter by `breadcrumb` seem not to be possible with wagtail Page
         ret = []
-        items = self.get_children().type(GenericPage).specific().live()
+        items = self.get_children().type(AGenericPage).specific().live()
         for item in items:
             if item.breadcrumb:
                 ret.append(item)
